@@ -1,24 +1,14 @@
 # Prompt/Timeout.pm
 #
-# $Id: Timeout.pm 37 2011-06-30 06:53:16Z stro $
-#
-# Copyright (c) 2008-2011 Serguei Trouchelle. All rights reserved.
+# Copyright (c) 2008 Serguei Trouchelle. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
 # History:
-#  1.04_04 2011/07/06 Continue struggling with failing reports, part 3
-#  1.04_03 2011/06/30 Continue struggling with failing reports, part 2
-#  1.04_02 2011/06/30 Continue struggling with failing reports
-#  1.04_01 2010/11/05 Added more prerequisites to find out what's wrong with some test reports
-#                     Rewrite tests with Test::More
-#  1.03    2010/11/01 Fixed problem with non-working "click", thanks to bottomsc[.]missouri.edu for reporting (RT#62535)
-#                     Fixed potential problem with TAP output parsing
-#  1.02    2009/08/31 Fixed problem with hanging in Unix environment, thanks to leocharre[.]cpan.org for reporting
-#  1.01    2008/05/23 Documentation typo
-#                     Removed Term::ReadKey::ReadMode because it doesn't work on some terminals
-#  1.00    2008/05/22 Initial revision
+#  1.01  2008/05/23 Documentation typo
+#                   Removed Term::ReadKey::ReadMode because it doesn't work on some terminals
+#  1.00  2008/05/22 Initial revision
 
 =head1 NAME
 
@@ -44,7 +34,7 @@ require Exporter;
 our @EXPORT = qw(prompt);
 our @ISA = qw(Exporter);
 
-$Prompt::Timeout::VERSION = '1.04_04';
+$Prompt::Timeout::VERSION = "1.01";
 
 =head1 DESCRIPTION
 
@@ -102,17 +92,15 @@ sub prompt ($;$$$) {
     while (1) {
       my $key = ReadKey(1); # 1 sec
       if (defined $key) {
-        last if $key =~ /^[\r\n]$/x;
+        last if $key eq "\r";
         $ans .= $key;
         print $key;
         $end = time + $timeout;
       } else {
-        unless ($click and $ans ne '') {
-          if ($end < time) {
-            $ans = $def;
-            print "$def\n";
-            last;
-          }
+        if ($end < time and not ($click and $ans ne '')) {
+          $ans = $def;
+          print "$def\n";
+          last;
         }
       }
     }
@@ -125,11 +113,11 @@ sub prompt ($;$$$) {
 
 Serguei Trouchelle E<lt>F<stro@railways.dp.ua>E<gt>
 
-Prompt::Timeout uses partial code from ExtUtils::MakeMaker module.
+FindBin::Real uses partial code from ExtUtils::MakeMaker module.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2011 Serguei Trouchelle. All rights reserved.
+Copyright (c) 2008 Serguei Trouchelle. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
